'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.noop = noop;
exports.checkStateToBoolean = checkStateToBoolean;
exports.booleanToCheckState = booleanToCheckState;
exports.ownerDocument = ownerDocument;
exports.ownerWindow = ownerWindow;
exports.addEventListener = addEventListener;
var TREE_ELEMENT = exports.TREE_ELEMENT = 'Tree';
var LIST_ELEMENT = exports.LIST_ELEMENT = 'List';
var ACTION_SELECT = exports.ACTION_SELECT = 'SELECT';
var ACTION_CHECK = exports.ACTION_CHECK = 'CHECK';
var CHECKBOX_CHECKED = exports.CHECKBOX_CHECKED = 1;
var CHECKBOX_UNCHECKED = exports.CHECKBOX_UNCHECKED = 0;
var CHECKBOX_PARTIAL = exports.CHECKBOX_PARTIAL = 2;
var ROOT_ID = exports.ROOT_ID = '-1';

function noop() {}

function checkStateToBoolean(state) {
  return state === CHECKBOX_CHECKED ? true : false;
}

function booleanToCheckState(state) {
  return state ? CHECKBOX_CHECKED : CHECKBOX_UNCHECKED;
}

function ownerDocument(node) {
  return node && node.ownerDocument || document;
}

function ownerWindow(node) {
  var doc = ownerDocument(node);
  return doc && doc.defaultView || doc.parentWindow;
}

var on = exports.on = function () {
  if (document.addEventListener) return function (node, eventName, handler, capture) {
    return node.addEventListener(eventName, handler, capture || false);
  };else if (document.attachEvent) return function (node, eventName, handler) {
    return node.attachEvent('on' + eventName, handler);
  };
}();

var off = exports.off = function () {
  if (document.addEventListener) return function (node, eventName, handler, capture) {
    return node.removeEventListener(eventName, handler, capture || false);
  };else if (document.attachEvent) return function (node, eventName, handler) {
    return node.detachEvent('on' + eventName, handler);
  };
}();

function addEventListener(node, event, handler, capture) {
  on(node, event, handler, capture);
  return {
    remove: function remove() {
      off(node, event, handler);
    }
  };
}